@@ -13,7 +13,18 @@ from collections import defaultdict
 from enum import IntEnum
 from io import TextIOBase
 from pathlib import Path
-from typing import Any, DefaultDict, Dict, List, Optional, Sequence, Set, Union, cast
+from typing import (
+    Any,
+    DefaultDict,
+    Dict,
+    List,
+    Optional,
+    Sequence,
+    Set,
+    Tuple,
+    Union,
+    cast,
+)
 from urllib.parse import ParseResult, urlparse
 
 import argcomplete
@@ -61,6 +72,13 @@ arg_parser.add_argument(
     '--url',
     help='Input file URL. `--input` is ignore when `--url` is used',
 )
+
+arg_parser.add_argument(
+    '--http-headers',
+    nargs='+',
+    metavar='HTTP_HEADER',
+    help='Set headers in HTTP requests to the remote host. (example: "Authorization: Basic dXNlcjpwYXNz")',
+)
 arg_parser.add_argument(
     '--input-file-type',
     help='Input file type (default: auto)',
@@ -86,7 +104,12 @@ arg_parser.add_argument(
     action='store_true',
     default=None,
 )
-
+arg_parser.add_argument(
+    '--use-annotated',
+    help='Use typing.Annotated for Field(). Also, `--field-constraints` option will be enabled.',
+    action='store_true',
+    default=None,
+)
 arg_parser.add_argument(
     '--field-extra-keys',
     help='Add extra keys to field parameters',
@@ -224,6 +247,13 @@ arg_parser.add_argument(
     default=None,
 )
 
+arg_parser.add_argument(
+    '--use-title-as-name',
+    help='use titles as class names of models',
+    action='store_true',
+    default=None,
+)
+
 arg_parser.add_argument(
     '--custom-template-dir', help='Custom template directory', type=str
 )
@@ -303,6 +333,22 @@ class Config(BaseModel):
                 )
         return values
 
+    @validator('http_headers', pre=True, each_item=True)
+    def validate_http_headers(cls, value: Any) -> Optional[Tuple[str, str]]:
+        if isinstance(value, str):  # pragma: no cover
+            try:
+                field_name, field_value = value.split(':', maxsplit=1)  # type: str, str
+                return field_name, field_value.lstrip()
+            except ValueError:
+                raise Error(f'Invalid http header: {value!r}')
+        return value  # pragma: no cover
+
+    @root_validator()
+    def validate_root(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        if values.get('use_annotated'):
+            values['field_constraints'] = True
+        return values
+
     input: Optional[Union[Path, str]]
     input_file_type: InputFileType = InputFileType.Auto
     output: Optional[Path]
@@ -338,6 +384,9 @@ class Config(BaseModel):
     field_include_all_keys: bool = False
     openapi_scopes: Optional[List[OpenAPIScope]] = None
     wrap_string_literal: Optional[bool] = None
+    use_title_as_name: bool = False
+    http_headers: Optional[Sequence[Tuple[str, str]]] = None
+    use_annotated: bool = False
 
     def merge_args(self, args: Namespace) -> None:
         for field_name in self.__fields__:
@@ -462,6 +511,9 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             field_include_all_keys=config.field_include_all_keys,
             openapi_scopes=config.openapi_scopes,
             wrap_string_literal=config.wrap_string_literal,
+            use_title_as_name=config.use_title_as_name,
+            http_headers=config.http_headers,
+            use_annotated=config.use_annotated,
         )
         return Exit.OK
     except InvalidClassNameError as e:
