@@ -283,6 +283,9 @@ class Parser(ABC):
         field_extra_keys: Optional[Set[str]] = None,
         field_include_all_keys: bool = False,
         wrap_string_literal: Optional[bool] = None,
+        use_title_as_name: bool = False,
+        http_headers: Optional[Sequence[Tuple[str, str]]] = None,
+        use_annotated: bool = False,
     ):
         self.data_type_manager: DataTypeManager = data_type_manager_type(
             target_python_version,
@@ -328,6 +331,7 @@ class Parser(ABC):
             remote_text_cache or DefaultPutDict()
         )
         self.current_source_path: Optional[Path] = None
+        self.use_title_as_name: bool = use_title_as_name
 
         if base_path:
             self.base_path = base_path
@@ -361,6 +365,12 @@ class Parser(ABC):
         )
         self.class_name: Optional[str] = class_name
         self.wrap_string_literal: Optional[bool] = wrap_string_literal
+        self.http_headers: Optional[Sequence[Tuple[str, str]]] = http_headers
+        self.use_annotated: bool = use_annotated
+        if self.use_annotated and not self.field_constraints:  # pragma: no cover
+            raise Exception(
+                '`use_annotated=True` has to be used with `field_constraints=True`'
+            )
 
     @property
     def iter_source(self) -> Iterator[Source]:
@@ -387,7 +397,9 @@ class Parser(ABC):
     def _get_text_from_url(self, url: str) -> str:
         from datamodel_code_generator.http import get_body
 
-        return self.remote_text_cache.get_or_put(url, default_factory=get_body)
+        return self.remote_text_cache.get_or_put(
+            url, default_factory=lambda url_: get_body(url, self.http_headers)
+        )
 
     @classmethod
     def get_url_path_parts(cls, url: ParseResult) -> List[str]:
