@@ -170,6 +170,7 @@ class JsonSchemaObject(BaseModel):
     exclusiveMaximum: Union[float, bool, None]
     exclusiveMinimum: Union[float, bool, None]
     additionalProperties: Union['JsonSchemaObject', bool, None]
+    patternProperties: Optional[Dict[str, 'JsonSchemaObject']]
     oneOf: List['JsonSchemaObject'] = []
     anyOf: List['JsonSchemaObject'] = []
     allOf: List['JsonSchemaObject'] = []
@@ -307,6 +308,9 @@ class JsonSchemaParser(Parser):
         field_extra_keys: Optional[Set[str]] = None,
         field_include_all_keys: bool = False,
         wrap_string_literal: Optional[bool] = None,
+        use_title_as_name: bool = False,
+        http_headers: Optional[Sequence[Tuple[str, str]]] = None,
+        use_annotated: bool = False,
     ):
         super().__init__(
             source=source,
@@ -346,6 +350,9 @@ class JsonSchemaParser(Parser):
             field_extra_keys=field_extra_keys,
             field_include_all_keys=field_include_all_keys,
             wrap_string_literal=wrap_string_literal,
+            use_title_as_name=use_title_as_name,
+            http_headers=http_headers,
+            use_annotated=use_annotated,
         )
 
         self.remote_object_cache: DefaultPutDict[str, Dict[str, Any]] = DefaultPutDict()
@@ -468,6 +475,8 @@ class JsonSchemaParser(Parser):
         # ignore an undetected object
         if ignore_duplicate_model and not fields and len(base_classes) == 1:
             return self.data_type(reference=base_classes[0])
+        if self.use_title_as_name and obj.title:
+            name = obj.title
         reference = self.model_resolver.add(path, name, class_name=True, loaded=True)
         self.set_additional_properties(reference.name, obj)
         data_model_type = self.data_model_type(
@@ -539,6 +548,7 @@ class JsonSchemaParser(Parser):
                     else None,
                     strip_default_none=self.strip_default_none,
                     extras={**self.get_field_extras(field)},
+                    use_annotated=self.use_annotated,
                 )
             )
         return fields
@@ -557,6 +567,8 @@ class JsonSchemaParser(Parser):
                 f'An object name must be unique.'
                 f'This argument will be removed in a future version'
             )
+        if self.use_title_as_name and obj.title:
+            name = obj.title
         reference = self.model_resolver.add(
             path,
             name,
@@ -589,6 +601,9 @@ class JsonSchemaParser(Parser):
         singular_name: bool = False,
         parent: Optional[JsonSchemaObject] = None,
     ) -> DataType:
+        if self.use_title_as_name and item.title:
+            name = item.title
+            singular_name = False
         if (
             parent
             and item.has_constraint
@@ -637,12 +652,27 @@ class JsonSchemaParser(Parser):
                 all_of_path,
                 ignore_duplicate_model=True,
             )
-        elif item.is_object:
+        elif item.is_object or item.patternProperties:
             object_path = get_special_path('object', path)
             if item.properties:
                 return self.parse_object(
                     name, item, object_path, singular_name=singular_name
                 )
+            elif item.patternProperties:
+                # support only single key dict.
+                return self.data_type(
+                    data_types=[
+                        self.data_type(
+                            data_types=[self.parse_item(name, v, object_path)],
+                            is_dict=True,
+                            dict_key=self.data_type_manager.get_data_type(
+                                Types.string,
+                                pattern=k,
+                            ),
+                        )
+                        for k, v in item.patternProperties.items()
+                    ],
+                )
             elif isinstance(item.additionalProperties, JsonSchemaObject):
                 return self.data_type(
                     data_types=[
@@ -737,6 +767,7 @@ class JsonSchemaParser(Parser):
             nullable=nullable,
             strip_default_none=self.strip_default_none,
             extras=self.get_field_extras(obj),
+            use_annotated=self.use_annotated,
         )
 
     def parse_array(
@@ -746,6 +777,8 @@ class JsonSchemaParser(Parser):
         path: List[str],
         original_name: Optional[str] = None,
     ) -> DataType:
+        if self.use_title_as_name and obj.title:
+            name = obj.title
         reference = self.model_resolver.add(path, name, loaded=True, class_name=True)
         field = self.parse_array_fields(original_name or name, obj, [*path, name])
 
@@ -768,6 +801,7 @@ class JsonSchemaParser(Parser):
                 nullable=field.nullable,
                 strip_default_none=field.strip_default_none,
                 extras=field.extras,
+                use_annotated=self.use_annotated,
             )
 
         data_model_root = self.data_model_root_type(
@@ -825,6 +859,8 @@ class JsonSchemaParser(Parser):
             required = not obj.nullable and not (
                 obj.has_default and self.apply_default_values_for_required_fields
             )
+        if self.use_title_as_name and obj.title:
+            name = obj.title
         reference = self.model_resolver.add(path, name, loaded=True, class_name=True)
         self.set_title(name, obj)
         self.set_additional_properties(name, obj)
@@ -839,6 +875,7 @@ class JsonSchemaParser(Parser):
                     nullable=obj.nullable if self.strict_nullable else None,
                     strip_default_none=self.strip_default_none,
                     extras=self.get_field_extras(obj),
+                    use_annotated=self.use_annotated,
                 )
             ],
             custom_base_class=self.base_class,
@@ -922,6 +959,8 @@ class JsonSchemaParser(Parser):
             self.results.append(enum)
             return self.data_type(reference=reference_)
 
+        if self.use_title_as_name and obj.title:
+            name = obj.title
         reference = self.model_resolver.add(
             path,
             name,
@@ -953,6 +992,7 @@ class JsonSchemaParser(Parser):
                     nullable=True,
                     strip_default_none=self.strip_default_none,
                     extras=self.get_field_extras(obj),
+                    use_annotated=self.use_annotated,
                 )
             ],
             custom_base_class=self.base_class,
@@ -1033,6 +1073,9 @@ class JsonSchemaParser(Parser):
                     self.parse_ref(item, path)
         if isinstance(obj.additionalProperties, JsonSchemaObject):
             self.parse_ref(obj.additionalProperties, path)
+        if obj.patternProperties:
+            for value in obj.patternProperties.values():
+                self.parse_ref(value, path)
         for item in obj.anyOf:
             self.parse_ref(item, path)
         for item in obj.allOf:
@@ -1054,6 +1097,9 @@ class JsonSchemaParser(Parser):
                     self.parse_id(item, path)
         if isinstance(obj.additionalProperties, JsonSchemaObject):
             self.parse_id(obj.additionalProperties, path)
+        if obj.patternProperties:
+            for value in obj.patternProperties.values():
+                self.parse_id(value, path)
         for item in obj.anyOf:
             self.parse_id(item, path)
         for item in obj.allOf:
@@ -1210,3 +1256,22 @@ class JsonSchemaParser(Parser):
                     reference = self.model_resolver.get(path)
                     if not reference or not reference.loaded:
                         self.parse_raw_obj(key, model, path)
+
+                key = tuple(path_parts)
+                reserved_refs = set(self.reserved_refs.get(key) or [])
+                while reserved_refs:
+                    for reserved_path in sorted(reserved_refs):
+                        reference = self.model_resolver.get(reserved_path)
+                        if not reference or reference.loaded:
+                            continue
+                        path = reserved_path.split('/')
+                        _, *object_paths = path
+                        models = get_model_by_path(raw, object_paths)
+                        model_name = object_paths[-1]
+                        self.parse_obj(
+                            model_name, JsonSchemaObject.parse_obj(models), path
+                        )
+                    previous_reserved_refs = reserved_refs
+                    reserved_refs = set(self.reserved_refs.get(key) or [])
+                    if previous_reserved_refs == reserved_refs:
+                        break
